Documentation
¶
Index ¶
Constants ¶
const ( OSWindows = "windows" OSLinux = "linux" OSMac = "mac" PkgDeb = "deb" PkgRPM = "rpm" RepoOrg = "org" RepoEnterprise = "enterprise" ArchArm64 = "arm64" ArchS390x = "s390x" ArchPpc64le = "ppc64le" ArchX86_64 = "x86_64" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Platform ¶
type Platform struct {
Name string
Arch string
OS string
Pkg string
Repos []string
BuildTags []string
BinaryExt string
}
Platform represents a platform (a combination of OS, distro, version, and architecture) on which we may build/test the tools. There should be at least one evergreen buildvariant per platform, and there may be multiple.
func DetectLocal ¶
DetectLocal detects the platform for non-evergreen use cases.
func GetByVariant ¶
func GetFromEnv ¶
GetFromEnv returns the Platform for this host, based on the value of EVG_VARIANT. It returns an error if EVG_VARIANT is unset or set to an unknown value.
func (Platform) ArtifactExtensions ¶
func (Platform) DebianArch ¶
Click to show internal directories.
Click to hide internal directories.